@@ -54,25 +54,19 @@ class GrlTrackerPlaylists(GObject.GObject):
         Grl.METADATA_KEY_URL
     ]
 
-    def __init__(
-            self, source, coremodel, application, grilo, tracker_wrapper,
-            songs_hash):
+    def __init__(self, source, application, tracker_wrapper, songs_hash):
         """Initialize GrlTrackerPlaylists.
 
         :param Grl.TrackerSource source: The Tracker source to wrap
-        :param CoreModel coremodel: CoreModel instance to use models
-                                    from
         :param Application application: Application instance
-        :param CoreGrilo grilo: The CoreGrilo instance
         :param TrackerWrapper tracker_wrapper: The TrackerWrapper
                                                instance
+        :param dict songs_hash: The songs hash table
         """
         super().__init__()
 
         self._application = application
-        self._coremodel = coremodel
-        self._coreselection = application.props.coreselection
-        self._grilo = grilo
+        self._coremodel = application.props.coremodel
         self._log = application.props.log
         self._source = source
         self._model = self._coremodel.props.playlists
@@ -96,7 +90,6 @@ class GrlTrackerPlaylists(GObject.GObject):
         args = {
             "source": self._source,
             "application": self._application,
-            "grilo": self._grilo,
             "tracker_wrapper": self._tracker_wrapper,
             "songs_hash": self._songs_hash
         }
@@ -150,10 +143,8 @@ class GrlTrackerPlaylists(GObject.GObject):
             return
 
         playlist = Playlist(
-            media=media, source=self._source, coremodel=self._coremodel,
-            application=self._application, grilo=self._grilo,
+            media=media, source=self._source, application=self._application,
             tracker_wrapper=self._tracker_wrapper, songs_hash=self._songs_hash)
-
         self._model.append(playlist)
         callback = data
         if callback is not None:
@@ -308,9 +299,7 @@ class Playlist(GObject.GObject):
 
     def __init__(
             self, media=None, query=None, tag_text=None, source=None,
-            coremodel=None, application=None, grilo=None,
-            tracker_wrapper=None, songs_hash=None):
-
+            application=None, tracker_wrapper=None, songs_hash=None):
         super().__init__()
         """Initialize a playlist
 
@@ -319,11 +308,9 @@ class Playlist(GObject.GObject):
        :param string tag_text: The non translatable unique identifier
             of the playlist
        :param Grl.Source source: The Grilo Tracker source object
-       :param CoreModel coremodel: The CoreModel instance
        :param Application application: The Application instance
-       :param CoreGrilo grilo: The CoreGrilo instance
-       :param TrackerWrapper tracker_wrapper: The TrackerWrapper
-            instance
+       :param TrackerWrapper tracker_wrapper: The TrackerWrapper instance
+       :param dict songs_hash: The songs hash table
         """
         if media:
             self.props.pl_id = media.get_id()
@@ -335,11 +322,11 @@ class Playlist(GObject.GObject):
 
         self.props.query = query
         self.props.tag_text = tag_text
+        self._application = application
         self._model = None
         self._source = source
-        self._coremodel = coremodel
+        self._coremodel = application.props.coremodel
         self._coreselection = application.props.coreselection
-        self._grilo = grilo
         self._log = application.props.log
         self._songs_hash = songs_hash
         self._tracker = tracker_wrapper.props.tracker
@@ -417,7 +404,7 @@ class Playlist(GObject.GObject):
                 self._window.notifications_popup.pop_loading()
                 return
 
-            coresong = CoreSong(media, self._coreselection, self._grilo)
+            coresong = CoreSong(self._application, media)
             self._bind_to_main_song(coresong)
             if coresong not in self._songs_todelete:
                 self._model.append(coresong)
@@ -610,7 +597,7 @@ class Playlist(GObject.GObject):
                 self.props.count = self._model.get_n_items()
                 return
 
-            coresong = CoreSong(media, self._coreselection, self._grilo)
+            coresong = CoreSong(self._application, media)
             self._bind_to_main_song(coresong)
             if coresong not in self._songs_todelete:
                 self._model.append(coresong)
@@ -765,7 +752,7 @@ class SmartPlaylist(Playlist):
                     self.emit("playlist-loaded")
                     return
 
-                coresong = CoreSong(media, self._coreselection, self._grilo)
+                coresong = CoreSong(self._application, media)
                 self._bind_to_main_song(coresong)
                 self._model.append(coresong)
 
@@ -818,7 +805,7 @@ class SmartPlaylist(Playlist):
 
         for idx, media in enumerate(new_model_medias):
             if media.get_id() not in current_models_ids:
-                coresong = CoreSong(media, self._coreselection, self._grilo)
+                coresong = CoreSong(self._application, media)
                 self._bind_to_main_song(coresong)
                 self._model.append(coresong)
                 self.props.count += 1
@@ -840,7 +827,6 @@ class MostPlayed(SmartPlaylist):
             ?song AS ?tracker_urn
             nie:title(?song) AS ?title
             nie:url(?song) AS ?url
-            nie:title(?song) AS ?title
             nmm:artistName(nmm:performer(?song)) AS ?artist
             nie:title(nmm:musicAlbum(?song)) AS ?album
             nfo:duration(?song) AS ?duration
@@ -877,7 +863,6 @@ class NeverPlayed(SmartPlaylist):
             ?song AS ?tracker_urn
             nie:title(?song) AS ?title
             nie:url(?song) AS ?url
-            nie:title(?song) AS ?title
             nmm:artistName(nmm:performer(?song)) AS ?artist
             nie:title(nmm:musicAlbum(?song)) AS ?album
             nfo:duration(?song) AS ?duration
@@ -920,7 +905,6 @@ class RecentlyPlayed(SmartPlaylist):
             ?song AS ?tracker_urn
             nie:title(?song) AS ?title
             nie:url(?song) AS ?url
-            nie:title(?song) AS ?title
             nmm:artistName(nmm:performer(?song)) AS ?artist
             nie:title(nmm:musicAlbum(?song)) AS ?album
             nfo:duration(?song) AS ?duration
@@ -966,7 +950,6 @@ class RecentlyAdded(SmartPlaylist):
             ?song AS ?tracker_urn
             nie:title(?song) AS ?title
             nie:url(?song) AS ?url
-            nie:title(?song) AS ?title
             nmm:artistName(nmm:performer(?song)) AS ?artist
             nie:title(nmm:musicAlbum(?song)) AS ?album
             nfo:duration(?song) AS ?duration
@@ -1004,7 +987,6 @@ class Favorites(SmartPlaylist):
                 ?song AS ?tracker_urn
                 nie:title(?song) AS ?title
                 nie:url(?song) AS ?url
-                nie:title(?song) AS ?title
                 nmm:artistName(nmm:performer(?song)) AS ?artist
                 nie:title(nmm:musicAlbum(?song)) AS ?album
                 nfo:duration(?song) AS ?duration
