@@ -24,7 +24,7 @@
 
 import gi
 gi.require_versions({"Gfm": "0.1", "Grl": "0.3", 'Tracker': "2.0"})
-from gi.repository import Gfm, Grl, GLib, GObject, Tracker
+from gi.repository import Gfm, Gio, Grl, GLib, GObject, Tracker
 
 from gnomemusic.corealbum import CoreAlbum
 from gnomemusic.coreartist import CoreArtist
@@ -71,18 +71,21 @@ class GrlTrackerWrapper(GObject.GObject):
         super().__init__()
 
         self._application = application
-        self._coremodel = application.props.coremodel
+        coremodel = application.props.coremodel
         self._log = application.props.log
-        self._songs_model = self._coremodel.props.songs
+        self._songs_model = Gio.ListStore.new(CoreSong)
+        coremodel.props.songs_proxy.append(self._songs_model)
         self._source = None
-        self._albums_model = self._coremodel.props.albums
+        self._albums_model = Gio.ListStore.new(CoreAlbum)
+        coremodel.props.albums_proxy.append(self._albums_model)
         self._album_ids = {}
-        self._artists_model = self._coremodel.props.artists
+        self._artists_model = Gio.ListStore.new(CoreArtist)
+        coremodel.props.artists_proxy.append(self._artists_model)
         self._artist_ids = {}
         self._hash = {}
-        self._song_search_proxy = self._coremodel.props.songs_search_proxy
-        self._album_search_model = self._coremodel.props.albums_search
-        self._artist_search_model = self._coremodel.props.artists_search
+        self._song_search_proxy = coremodel.props.songs_search_proxy
+        self._album_search_model = coremodel.props.albums_search
+        self._artist_search_model = coremodel.props.artists_search
         self._batch_changed_media_ids = {}
         self._content_changed_timeout = None
         self._tracker_playlists = None
@@ -100,9 +103,9 @@ class GrlTrackerWrapper(GObject.GObject):
         self._content_changed_id = None
         self.props.source = source
 
-        self._initial_songs_fill(self.props.source)
-        self._initial_albums_fill(self.props.source)
-        self._initial_artists_fill(self.props.source)
+        self._initial_songs_fill()
+        self._initial_albums_fill()
+        self._initial_artists_fill()
 
     @GObject.Property(type=Grl.Source, default=None)
     def source(self):
@@ -367,7 +370,7 @@ class GrlTrackerWrapper(GObject.GObject):
             self._song_media_query(media_ids), self.METADATA_KEYS,
             options, _update_changed_media)
 
-    def _initial_songs_fill(self, source):
+    def _initial_songs_fill(self):
         self._window.notifications_popup.push_loading()
         songs_added = []
 
@@ -432,7 +435,7 @@ class GrlTrackerWrapper(GObject.GObject):
         self.props.source.query(
             query, self.METADATA_KEYS, options, _add_to_model)
 
-    def _initial_albums_fill(self, source):
+    def _initial_albums_fill(self):
         self._window.notifications_popup.push_loading()
         albums_added = []
 
@@ -484,9 +487,10 @@ class GrlTrackerWrapper(GObject.GObject):
 
         options = self._fast_options.copy()
 
-        source.query(query, self.METADATA_KEYS, options, _add_to_albums_model)
+        self.props.source.query(
+            query, self.METADATA_KEYS, options, _add_to_albums_model)
 
-    def _initial_artists_fill(self, source):
+    def _initial_artists_fill(self):
         self._window.notifications_popup.push_loading()
         artists_added = []
 
@@ -535,7 +539,7 @@ class GrlTrackerWrapper(GObject.GObject):
 
         options = self._fast_options.copy()
 
-        source.query(
+        self.props.source.query(
             query, [Grl.METADATA_KEY_ARTIST], options, _add_to_artists_model)
 
     def get_artist_albums(self, media, model):
