@@ -43,6 +43,8 @@ class AlbumsView(Gtk.Stack):
 
     search_mode_active = GObject.Property(type=bool, default=False)
     selection_mode = GObject.Property(type=bool, default=False)
+    title = GObject.Property(
+        type=str, default=_("Albums"), flags=GObject.ParamFlags.READABLE)
 
     _scrolled_window = Gtk.Template.Child()
     _flowbox = Gtk.Template.Child()
@@ -55,9 +57,7 @@ class AlbumsView(Gtk.Stack):
         """
         super().__init__(transition_type=Gtk.StackTransitionType.CROSSFADE)
 
-        # FIXME: Make these properties.
-        self.name = "albums"
-        self.title = _("Albums")
+        self.props.name = "albums"
 
         self._application = application
         self._window = application.props.window
@@ -227,14 +227,11 @@ class AlbumsView(Gtk.Stack):
         if self.props.selection_mode is False:
             self.props.selection_mode = True
 
-        rubberband_selection = len(self._flowbox.get_selected_children()) > 1
         with self._application.props.coreselection.freeze_notify():
-            if (rubberband_selection
-                    and not self._ctrl_hold):
+            if self._ctrl_hold is False:
                 self.deselect_all()
             for child in self._flowbox.get_selected_children():
-                if (self._ctrl_hold is True
-                        or not rubberband_selection):
+                if self._ctrl_hold is True:
                     child.props.selected = not child.props.selected
                 else:
                     child.props.selected = True
