@@ -58,6 +58,8 @@ class SearchView(Gtk.Stack):
     search_state = GObject.Property(type=int, default=Search.State.NONE)
     selection_mode = GObject.Property(type=bool, default=False)
     state = GObject.Property(type=int, default=State.MAIN)
+    title = GObject.Property(
+        type=str, default="", flags=GObject.ParamFlags.READABLE)
 
     _album_header = Gtk.Template.Child()
     _album_flowbox = Gtk.Template.Child()
@@ -79,9 +81,7 @@ class SearchView(Gtk.Stack):
         """
         super().__init__(transition_type=Gtk.StackTransitionType.CROSSFADE)
 
-        # FIXME: Make these properties.
-        self.name = "search"
-        self.title = None
+        self.props.name = "search"
 
         self._application = application
         self._coremodel = application.props.coremodel
@@ -298,7 +298,7 @@ class SearchView(Gtk.Stack):
         if nb_children == 0:
             return
 
-        first_child = self._album_flowbox.get_child_at_index(0)
+        first_child = self._artist_flowbox.get_child_at_index(0)
         # FIXME: It looks like it is possible that the widget is not
         # yet created, resulting in a crash with first_child being
         # None.
@@ -354,7 +354,7 @@ class SearchView(Gtk.Stack):
             return
 
         artist_albums_widget = ArtistAlbumsWidget(
-            coreartist, self._application, True)
+            coreartist, self._application)
         # FIXME: Recreating a view here. Alternate solution is used
         # in AlbumsView: one view created and an update function.
         # Settle on one design.
