@@ -116,8 +116,8 @@ class AlbumWidget(Gtk.EventBox):
         self._album_model.items_changed(0, 0, 0)
 
     def _create_widget(self, disc):
-        disc_box = self._create_disc_box(
-            disc.props.disc_nr, disc.model)
+        disc_box = DiscBox(disc)
+        disc_box.connect('song-activated', self._song_activated)
 
         self._disc_list_box.bind_property(
             "selection-mode", disc_box, "selection-mode",
@@ -126,16 +126,6 @@ class AlbumWidget(Gtk.EventBox):
 
         return disc_box
 
-    def _create_disc_box(self, disc_nr, album_model):
-        disc_box = DiscBox(album_model)
-        disc_box.set_disc_number(disc_nr)
-        disc_box.props.show_durations = True
-        disc_box.props.show_favorites = True
-        disc_box.props.show_song_numbers = True
-        disc_box.connect('song-activated', self._song_activated)
-
-        return disc_box
-
     def _on_model_items_changed(self, model, position, removed, added):
         n_items = model.get_n_items()
         if n_items == 1:
