@@ -40,15 +40,18 @@ class ArtistAlbumsWidget(Gtk.ListBox):
 
     selection_mode = GObject.Property(type=bool, default=False)
 
-    def __init__(
-            self, coreartist, application, selection_mode_allowed=False):
+    def __init__(self, coreartist, application):
+        """Initialize the ArtistAlbumsWidget
+
+        :param CoreArtist coreartist: The CoreArtist object
+        :param Aplication application: The Application object
+        """
         super().__init__()
 
         self._application = application
         self._artist = coreartist.props.artist
         self._model = coreartist.props.model
         self._player = self._application.props.player
-        self._selection_mode_allowed = selection_mode_allowed
 
         self._cover_size_group = Gtk.SizeGroup.new(
             Gtk.SizeGroupMode.HORIZONTAL)
@@ -58,11 +61,9 @@ class ArtistAlbumsWidget(Gtk.ListBox):
         self.bind_model(self._model, self._add_album)
 
         self.get_style_context().add_class("artist-albums-widget")
-        self.show_all()
+        self.props.visible = True
 
     def _song_activated(self, widget, song_widget):
-        self._album = None
-
         if self.props.selection_mode:
             return
 
@@ -81,8 +82,7 @@ class ArtistAlbumsWidget(Gtk.ListBox):
         row.props.activatable = False
 
         widget = ArtistAlbumWidget(
-            corealbum, self._selection_mode_allowed,
-            self._songs_grid_size_group, self._cover_size_group)
+            corealbum, self._songs_grid_size_group, self._cover_size_group)
 
         self.bind_property(
             'selection-mode', widget, 'selection-mode',
